@@ -1,8 +1,9 @@
 #![cfg_attr(not(feature = "std"), no_std)]
 #![feature(cfg_version)]
-#![feature(generic_associated_types)] // For mutex, http, http::client, http::server, ota and ghota
+#![feature(generic_associated_types)] // For mutex, http, http::client, http::server, ota, ghota and all asyncs; soon to be stabilized
+#![feature(cfg_target_has_atomic)] // Soon to be stabilized
+#![cfg_attr(feature = "experimental", feature(type_alias_impl_trait))] // For the Sender/Receiver adapters; hopefully soon to be stabilized
 #![cfg_attr(version("1.61"), allow(deprecated_where_clause_location))]
-#![cfg_attr(feature = "experimental", feature(type_alias_impl_trait))] // For the Sender/Receiver adapters
 
 #[cfg(feature = "alloc")]
 #[allow(unused_imports)]
