@@ -1,10 +1,10 @@
-#[cfg(feature = "alloc")]
+#[cfg(all(feature = "alloc", target_has_atomic = "ptr"))]
 pub mod event_bus;
-#[cfg(feature = "alloc")]
+#[cfg(all(feature = "alloc", target_has_atomic = "ptr"))]
 pub mod mqtt;
-#[cfg(feature = "alloc")]
+#[cfg(all(feature = "alloc", target_has_atomic = "ptr"))]
 pub mod timer;
-#[cfg(feature = "alloc")]
+#[cfg(all(feature = "alloc", feature = "heapless", target_has_atomic = "ptr"))]
 pub mod ws;
 
 pub trait AsyncWrapper<S> {
