@@ -3,8 +3,8 @@ use core::pin::Pin;
 use core::task::{Context, Poll};
 
 pub mod channel;
-#[cfg(all(feature = "isr-async-executor", feature = "alloc"))]
 pub mod executor;
+pub mod select;
 pub mod signal;
 
 /// Yield from the current task once, allowing other tasks to run.
